@@ -1,4 +1,4 @@
-"""
+'''
 # aws-kinesisstreams-lambda module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -32,7 +32,7 @@ Here is a minimal deployable pattern definition in Typescript:
 const { KinesisStreamsToLambda } from '@aws-solutions-constructs/aws-kinesisstreams-lambda';
 
 new KinesisStreamsToLambda(this, 'KinesisToLambdaPattern', {
-    eventSourceProps: {
+    kinesisEventSourceProps: {
         startingPosition: lambda.StartingPosition.TRIM_HORIZON,
         batchSize: 1
     },
@@ -105,7 +105,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -130,9 +130,9 @@ class KinesisStreamsToLambda(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambda",
 ):
-    """
+    '''
     :summary: The KinesisStreamsToLambda class.
-    """
+    '''
 
     def __init__(
         self,
@@ -148,7 +148,7 @@ class KinesisStreamsToLambda(
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
@@ -163,7 +163,7 @@ class KinesisStreamsToLambda(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the KinesisStreamsToLambda class.
-        """
+        '''
         props = KinesisStreamsToLambdaProps(
             create_cloud_watch_alarms=create_cloud_watch_alarms,
             deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
@@ -222,7 +222,7 @@ class KinesisStreamsToLambdaProps:
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
-        """The properties for the KinesisStreamsToLambda class.
+        '''The properties for the KinesisStreamsToLambda class.
 
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
@@ -232,7 +232,7 @@ class KinesisStreamsToLambdaProps:
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
-        """
+        '''
         if isinstance(kinesis_stream_props, dict):
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
@@ -259,55 +259,55 @@ class KinesisStreamsToLambdaProps:
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
-        """Whether to create recommended CloudWatch alarms.
+        '''Whether to create recommended CloudWatch alarms.
 
         :default: - Alarms are created
-        """
+        '''
         result = self._values.get("create_cloud_watch_alarms")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
-        """Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue.
+        '''Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue.
 
         :default: - true.
-        """
+        '''
         result = self._values.get("deploy_sqs_dlq_queue")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_stream_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_event_source_props(self) -> typing.Any:
-        """Optional user-provided props to override the default props for the Lambda event source mapping.
+        '''Optional user-provided props to override the default props for the Lambda event source mapping.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("kinesis_event_source_props")
         return typing.cast(typing.Any, result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
-        """Optional user-provided props to override the default props for the Kinesis stream.
+        '''Optional user-provided props to override the default props for the Kinesis stream.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("kinesis_stream_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
@@ -315,19 +315,19 @@ class KinesisStreamsToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """User provided props to override the default props for the Lambda function.
+        '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
-        """Optional user provided properties for the SQS dead letter queue.
+        '''Optional user provided properties for the SQS dead letter queue.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("sqs_dlq_queue_props")
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
 
